@@ -1,7 +1,7 @@
 import lab as B
 from algebra import proven
 
-from ..constant import Zero, Constant
+from ..constant import Constant, Zero
 from ..kronecker import Kronecker
 from ..matrix import AbstractMatrix
 
@@ -40,4 +40,4 @@ def kron(a: AbstractMatrix, b: AbstractMatrix):
 
 @B.dispatch
 def kron(a: Constant, b: Constant):
-    return Constant(B.multiply(a.const, b.const), *_product_shape(a, b))
\ No newline at end of file
+    return Constant(B.multiply(a.const, b.const), *_product_shape(a, b))
