@@ -3,7 +3,7 @@ from typing import Union
 import lab as B
 from wbml.warning import warn_upmodule
 
-from ..constant import Zero, Constant
+from ..constant import Constant, Zero
 from ..diagonal import Diagonal
 from ..kronecker import Kronecker
 from ..lowrank import LowRank
@@ -70,4 +70,4 @@ def root(a: Union[LowRank, Woodbury]):
 
 @B.dispatch
 def root(a: Kronecker):
-    return Kronecker(B.root(a.left), B.root(a.right))
\ No newline at end of file
+    return Kronecker(B.root(a.left), B.root(a.right))
