@@ -1,18 +1,24 @@
 import lab as B
+import pytest
+
+from matrix import AbstractMatrix
 
 # noinspection PyUnresolvedReferences
 from ..util import (
+    AssertDenseWarning,
     approx,
-    mat1,
-    zero1,
+    const1,
     dense1,
     diag1,
-    const1,
-    lt1,
-    ut1,
-    lr1,
-    wb1,
     kron1,
+    lr1,
+    lt1,
+    mat1,
+    tb1,
+    tb_axis,
+    ut1,
+    wb1,
+    zero1,
 )
 
 
@@ -20,6 +26,18 @@ def _check_cache(a):
     assert B.dense(a) is B.dense(a)
 
 
+def test_dense_unknown():
+    class MyMat(AbstractMatrix):
+        def __str__(self):
+            return "MyMat"
+
+        def __repr__(self):
+            return "MyMat"
+
+    with pytest.raises(RuntimeError):
+        B.dense(MyMat())
+
+
 def test_dense_zero(zero1):
     approx(B.dense(zero1), B.zeros(zero1.rows, zero1.cols))
     _check_cache(zero1)
@@ -74,3 +92,27 @@ def test_dense_wb(wb1):
 def test_dense_kron(kron1):
     approx(B.dense(kron1), B.kron(B.dense(kron1.left), B.dense(kron1.right)))
     _check_cache(kron1)
+
+
+def test_dense_tb(tb1):
+    with AssertDenseWarning(["tiling", "concatenating"]):
+        approx(
+            B.dense(tb1),
+            B.concat(
+                *sum(
+                    [
+                        (B.dense(block),) * rep
+                        for block, rep in zip(tb1.blocks, tb1.reps)
+                    ],
+                    (),
+                ),
+                axis=tb1.axis
+            ),
+        )
+    _check_cache(tb1)
+
+
+def test_dense_tb_axis(tb1):
+    tb1.axis = 3
+    with pytest.raises(RuntimeError):
+        B.dense(tb1)
